<?php
/**
 * Customize Settings Default Choices provider
 *
 * @package    Community_Builder
 * @subpackage Customizer
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Helps provide default setting choices.
 */
class CB_Settings_Choices {

	/**
	 * Get an array of choices.
	 *
	 * @param string $setting setting name.
	 *
	 * @return array
	 */
	public static function get( $setting ) {

		if ( is_object( $setting ) ) {
			$setting = $setting->id;
		}

		$choices = array( 0 );

		switch ( $setting ) {

			case 'layout-style':
				$choices = array(
					'boxed' => __( 'Boxed Layout', 'community-builder' ),
					'fluid' => __( 'Fluid Layout', 'community-builder' ),
				);

				break;

			case 'theme-layout':
				$choices = cb_get_global_layouts();
				break;

			case 'home-layout':
			case 'archive-layout':
			case 'search-layout':
			case '404-layout':
			case 'bp-activity-directory-layout':
			case 'bp-members-directory-layout':
			case 'bp-member-profile-layout':
			case 'bp-groups-directory-layout':
			case 'bp-create-group-layout':
			case 'bp-single-group-layout':
			case 'bp-blogs-directory-layout':
			case 'bp-create-blog-layout':
			case 'bp-signup-page-layout':
			case 'bp-activation-page-layout':
				$choices = cb_get_page_layouts();
				break;

			case 'site-header-rows':
				$choices = array(
					'top'    => __( 'Top Row', 'community-builder' ),
					'main'   => __( 'Main Row', 'community-builder' ),
					'bottom' => __( 'Bottom Row', 'community-builder' ),
				);
				break;

			case 'site-header-row-top-preset':
				$choices = cb_get_site_header_row_presets( 'top' );
				break;

			case 'site-header-row-main-preset':
				$choices = cb_get_site_header_row_presets( 'main' );
				break;

			case 'site-header-row-bottom-preset':
				$choices = cb_get_site_header_row_presets( 'bottom' );
				break;

			case 'panel-left-visibility':
			case 'panel-right-visibility':
			case 'site-header-row-visibility':
			case 'site-header-row-top-visibility':
			case 'site-header-row-main-visibility':
			case 'site-header-row-bottom-visibility':
				$choices = array(
					'all'     => __( 'All', 'community-builder' ),
					'mobile'  => __( 'Small Screen only', 'community-builder' ),
					'desktop' => __( 'Desktop only', 'community-builder' ),
					'none'   => __( 'None', 'community-builder' ),
				);
				break;

			case 'panel-left-user-scope':
			case 'panel-right-user-scope':
			case 'site-header-row-user-scope':
			case 'site-header-row-top-user-scope':
			case 'site-header-row-main-user-scope':
			case 'site-header-row-bottom-user-scope':
				$choices = array(
					'all'        => __( 'Everyone', 'community-builder' ),
					'logged-in'  => __( 'Logged In', 'community-builder' ),
					'logged-out' => __( 'Logged Out', 'community-builder' ),
				);

				break;

			case 'header-social-icons':
			case 'footer-social-icons':
				$choices = array(
					// not adding translations for brand names.
					'facebook'    => 'Facebook',
					'twitter'     => 'Twitter',
					'linkedin'    => 'LinkedIn',
					'google-plus' => 'Google+',
					'youtube'     => 'Youtube',
					'vimeo'       => 'Vimeo',
					'instagram'   => 'Instagram',
					'flickr'      => 'Flickr',
					'pinterest'   => 'Pinterest',
					'rss'         => __( 'RSS', 'community-builder' ),
					'email'       => __( 'Email', 'community-builder' ),
				);
				break;

			case 'footer-enabled-widget-areas':
				$choices = array(
					0 => __( 'None', 'community-builder' ),
					1 => __( 'One', 'community-builder' ),
					2 => __( 'Two', 'community-builder' ),
					3 => __( 'Three', 'community-builder' ),
					4 => __( 'Four', 'community-builder' ),
				);
				break;

			case 'font-style-body':
				$choices = array(
					'normal' => __( 'Normal', 'community-builder' ),
					'italic' => __( 'Italic', 'community-builder' ),
				);
				break;

			case 'text-transform-body':
				$choices = array(
					'none'      => __( 'None', 'community-builder' ),
					'uppercase' => __( 'Uppercase', 'community-builder' ),
					'lowercase' => __( 'Lowercase', 'community-builder' ),
				);
				break;

			case 'link-underline-body':
				$choices = array(
					'always' => __( 'Always', 'community-builder' ),
					'hover'  => __( 'On hover/focus', 'community-builder' ),
					'never'  => __( 'Never', 'community-builder' ),
				);
				break;

			case 'main-menu-selected-item-font-weight':
			case 'sub-menu-selected-item-font-weight':
			case 'header-bottom-menu-selected-item-font-weight':
			case 'header-bottom-sub-menu-selected-item-font-weight':
			case 'quick-menu-1-selected-item-font-weight':
			case 'panel-left-menu-selected-item-font-weight':
			case 'panel-left-sub-menu-selected-item-font-weight':
			case 'panel-right-menu-selected-item-font-weight':
			case 'panel-right-sub-menu-selected-item-font-weight':
				$choices = array(
					'normal' => __( 'Normal', 'community-builder' ),
					'bold'   => __( 'Bold', 'community-builder' ),
				);
				break;

			case 'main-menu-alignment':
			case 'header-bottom-menu-alignment':
			case 'quick-menu-1-alignment':
				$choices = array(
					'left'   => __( 'Left', 'community-builder' ),
					'center' => __( 'Center', 'community-builder' ),
					'right'  => __( 'Right', 'community-builder' ),
				);

				break;

			case 'page-page-header-items':
				$choices = array(
					'title'   => __( 'Title', 'community-builder' ),
					'tagline' => __( 'Tagline', 'community-builder' ),
				);
				break;

			case 'post-page-header-items':
				$choices = array(
					'title'   => __( 'Title', 'community-builder' ),
					'tagline' => __( 'Tagline', 'community-builder' ),
					'meta'    => __( 'Meta', 'community-builder' ),
				);
				break;

			case 'archive-page-header-items':
				$choices = array(
					'title'       => __( 'Title', 'community-builder' ),
					'description' => __( 'Term description', 'community-builder' ),
				);
				break;

			case 'page-article-items':
				$choices = array(
					'title'          => __( 'Title', 'community-builder' ),
					'featured-image' => __( 'Featured Image', 'community-builder' ),
				);
				break;

			case 'post-article-items':
			case 'archive-article-items':
				$choices = array(
					'title'          => __( 'Title', 'community-builder' ),
					'featured-image' => __( 'Featured Image', 'community-builder' ),
					'meta'           => __( 'Meta', 'community-builder' ),
				);
				break;

			case 'post-header-meta':
			case 'post-footer-meta':
			case 'archive-post-footer-meta':
			case 'archive-post-header-meta':
				$choices = array(
					'author'     => __( 'Author', 'community-builder' ),
					'post-date'  => __( 'Post Date', 'community-builder' ),
					'categories' => __( 'Categories', 'community-builder' ),
					'tags'       => __( 'Tags', 'community-builder' ),
					'comments'   => __( 'Comments', 'community-builder' ),
				);

				break;

			case 'archive-posts-display-type':
			case 'home-posts-display-type':
			case 'search-posts-display-type':
				$choices = array(
					'masonry'  => __( 'Masonry Grids', 'community-builder' ),
					'standard' => __( 'Standard list', 'community-builder' ),
				);

				break;

			case 'bp-item-list-display-type':
				$choices = array(
					'grid' => __( 'Grid Layout', 'community-builder' ),
					'list' => __( 'List layout', 'community-builder' ),
				);

				break;

			case 'bp-item-list-grid-type':
				$choices = array(
					'masonry'     => __( 'Masonry grid', 'community-builder' ),
					'equalheight' => __( 'Equal height grid', 'community-builder' ),
				);
				break;

			case 'bp-item-list-item-display-type':
				$choices = array(
					'card'    => __( 'Card view', 'community-builder' ),
					'box'     => __( 'Box view', 'community-builder' ),
					'regular' => __( 'Regular view', 'community-builder' ),
				);
				break;

			case 'bp-dir-nav-style':
			case 'bp-item-sub-nav-style':
				$choices = array(
					'default' => __( 'Default', 'community-builder' ),
					'curved'  => __( 'Curved', 'community-builder' ),
				);
				break;

			case 'bp-item-primary-nav-style':
				$choices = array(
					'default'   => __( 'Default', 'community-builder' ),
					'icon-left' => __( 'Icon + Label', 'community-builder' ),
					'icon-top'  => __( 'Icon / Label', 'community-builder' ),
					'icon-only' => __( 'Icon Only', 'community-builder' ),
				);
				break;

			case 'button-list-display-type':
				$choices = array(
					'dropdown' => __( 'Split dropdown buttons', 'community-builder' ),
					'list'     => __( 'Normal buttons', 'community-builder' ),
				);

				break;

			case 'bp-member-profile-header-style':
				$choices = cb_bp_get_item_header_styles( 'members' );
				break;
			case 'bp-single-group-header-style':
				$choices = cb_bp_get_item_header_styles( 'groups' );
				break;

			case 'bp-activity-list-style':
				$choices = array(
					'activity-list-style-default' => __( 'Default', 'community-builder' ),
					'activity-list-style-2'       => __( 'Style 2', 'community-builder' ),
				);
				break;
			case 'bp-member-profile-header-fields':
			case 'bp-members-list-profile-fields':
				$choices = cb_bp_get_all_profile_fields();
				break;
		}

		/**
		 * Filter the setting choices.
		 *
		 * @param array $choices Choices for the setting.
		 * @param string $setting Setting name.
		 */
		return apply_filters( 'cb_setting_choices', $choices, $setting );
	}
}
